@@ -1,10 +1,10 @@
 import logging
 import time
+from queue import Queue
 from threading import Lock
 from threading import Thread
 
 from pyrsistent import m
-from six.moves.queue import Queue
 
 from task_processing.interfaces.task_executor import TaskExecutor
 
